@@ -22,7 +22,7 @@ impl Date {
     /// # Returns
     /// `none` if the date is invalid, otherwise a new date.
     #[must_use]
-    pub fn new_ymd(year: i32, month: u8, day: u8) -> Option<Date> {
+    pub const fn new_ymd(year: i32, month: u8, day: u8) -> Option<Date> {
         if is_valid_day(year, month, day) {
             return Some(Date { year,
                                month,
@@ -58,19 +58,17 @@ impl Date {
     /// # Returns
     /// A boolean value.
     #[must_use]
-    pub fn leap_year(&self) -> &bool {
+    pub const fn leap_year(&self) -> &bool {
         &self.leap_year
     }
-
     /// Gets the year.
     ///
     /// # Returns
     /// A `&i32`.
     #[must_use]
-    pub fn year(&self) -> &i32 {
+    pub const fn year(&self) -> &i32 {
         &self.year
     }
-
     /// Sets the year.
     ///
     /// # Returns
@@ -82,16 +80,14 @@ impl Date {
         }
         self.year = year;
     }
-
     /// Gets the month.
     ///
     /// # Returns
     /// A `&u8`.
     #[must_use]
-    pub fn month(&self) -> &u8 {
+    pub const fn month(&self) -> &u8 {
         &self.month
     }
-
     /// Sets the month.
     ///
     /// # Returns
@@ -102,16 +98,13 @@ impl Date {
             false => { panic!("Error: Invalid month.") }
         }
     }
-
-
     /// Gets the day.
     ///
     /// # Returns
     /// A `&u8`.
-    pub fn day(&self) -> &u8 {
+    pub const fn day(&self) -> &u8 {
         &self.day
     }
-
     /// Sets the day.
     ///
     /// # Returns
@@ -122,16 +115,14 @@ impl Date {
             false => { panic!("Error: Invalid day.") }
         }
     }
-
     /// Gets the hour.
     ///
     /// # Returns
     /// A `&u8`.
     #[must_use]
-    pub fn hour(&self) -> &u8 {
+    pub const fn hour(&self) -> &u8 {
         &self.hour
     }
-
     /// Sets the hour.
     ///
     /// # Returns
@@ -142,16 +133,14 @@ impl Date {
             false => { panic!("Error: Invalid hour.") }
         }
     }
-
     /// Gets the minute.
     ///
     /// # Returns
     /// A `&u8`.
     #[must_use]
-    pub fn minute(&self) -> &u8 {
+    pub const fn minute(&self) -> &u8 {
         &self.minute
     }
-
     /// Sets the minute.
     ///
     /// # Returns
@@ -162,16 +151,14 @@ impl Date {
             false => { panic!("Error: Invalid minute.") }
         }
     }
-
     /// Gets the second.
     ///
     /// # Returns
     /// A `&u8`.
     #[must_use]
-    pub fn second(&self) -> &u8 {
+    pub const fn second(&self) -> &u8 {
         &self.second
     }
-
     /// Sets the second.
     ///
     /// # Returns
@@ -184,7 +171,7 @@ impl Date {
     }
 }
 
-fn is_valid_day(year: i32, month: u8, day: u8) -> bool {
+const fn is_valid_day(year: i32, month: u8, day: u8) -> bool {
     let day_in_month: u8;
 
     match month {
@@ -202,7 +189,6 @@ fn is_valid_day(year: i32, month: u8, day: u8) -> bool {
     if day <= day_in_month { return true; }
     false
 }
-
 /// Checks if a year is a leap year.
 ///
 /// # Arguments
@@ -211,11 +197,11 @@ fn is_valid_day(year: i32, month: u8, day: u8) -> bool {
 /// A boolean value.
 #[inline]
 #[must_use]
-pub fn is_leap_year(year: i32) -> bool {
+pub const fn is_leap_year(year: i32) -> bool {
     year & 3 == 0 && (year & 24 == 0 || year & 15 == 0)
 }
 #[inline]
-fn is_valid_hms(hour: u8, minute: u8, second: u8) -> bool {
+const fn is_valid_hms(hour: u8, minute: u8, second: u8) -> bool {
     hour <= 24 && minute <= 60 && second <= 60
 }
 
