@@ -131,7 +131,22 @@ pub trait MapToNumRange<T> {
     #[must_use]
     fn map_to(&self, start1: T, end1: T, start2: T, end2: T) -> T;
 }
-
+/// Trait for determining whether a number is in a given range.
+pub trait IsInRange {
+    /// Determine whether `self` is in the interval `[start; end]`.
+    /// # Returns
+    /// A `bool`.
+    /// # Examples
+    /// ```
+    /// use lib_rapid::math::general::IsInRange;
+    /// 
+    /// assert_eq!(true, 5.is_in_range(0, 10));
+    /// assert_eq!(true, 5.is_in_range(0, 5));
+    /// assert_eq!(false, 3.14.is_in_range(5.0, 10.0));
+    /// ```
+    #[must_use]
+    fn is_in_range(&self, start: Self, end: Self) -> bool;
+}
 /// Common powers.
 pub trait CommonPowers {
     /// Square a number.
@@ -225,6 +240,13 @@ pub trait Decrement {
     fn dec_by(&mut self, n: Self);
 }
 
+impl<T: std::cmp::PartialOrd> IsInRange for T {
+    #[inline]
+    fn is_in_range(&self, start: Self, end: Self) -> bool {
+        self >= &start && self <= &end
+    }
+}
+
 impl<T: std::ops::AddAssign + From<u8>> Increment for T {
     #[inline]
     fn inc(&mut self) {
@@ -318,6 +340,7 @@ impl<T: std::ops::Mul<Output = T> + Copy> CommonPowers for T {
 /// use lib_rapid::math::constants;
 /// assert_eq!(constants::SQRT2, nth_root(2.0, 2.0));
 /// ```
+#[must_use]
 #[inline]
 pub fn nth_root(degree: f64, radicand: f64) -> f64 {
     radicand.powf(degree.recip())
@@ -334,6 +357,7 @@ pub fn nth_root(degree: f64, radicand: f64) -> f64 {
 /// assert_eq!(1304969544928657, nth_fibonacci(74));
 /// assert_eq!(332825110087067562321196029789634457848, nth_fibonacci(186));
 /// ```
+#[must_use]
 pub fn nth_fibonacci(n: u128) -> u128 {
     if n > 186
     { panic!("Error: The 187th Fibonacci number and all above are not allowed, as they would cause a overflow in the u128 type."); }
